Quiz class

Constructors

Quiz({required List<QuestionModel> questions, int? timerDuration})
Constructor

Properties

hashCode int
The hash code for this object.
no setterinherited
questions List<QuestionModel>
List of questions in the quiz
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timerDuration int?
Timer duration in seconds, default is 120 seconds
getter/setter pair
totalAccuracy int
Calculates the accuracy as a percentage
no setter
totalCorrectAnswers int
Calculates the total number of correct answers
no setter
totalIncorrectAnswers int
Calculates the total number of incorrect answers
no setter
totalQuestions int
Getter for total number of questions
no setter
totalSkippedQuestions int
Calculates the total number of skipped questions
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited